==> hibiscus.js-1.2.2.tgz: package/notification/notification-container.component.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Component, Inject, Optional } from '@angular/core';
import { MessageContainerComponent } from '../message/message-container.component';
import { NOTIFICATION_CONFIG, NOTIFICATION_DEFAULT_CONFIG } from './notification-config';
var NotificationContainerComponent = /** @class */ (function (_super) {
    __extends(NotificationContainerComponent, _super);
    function NotificationContainerComponent(defaultConfig, config) {
        return _super.call(this, defaultConfig, config) || this;
    }
    NotificationContainerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'hi-notification-container',
                    preserveWhitespaces: false,
                    template: "\n    <div class=\"hi-notification hi-notification-{{config.hiPlacement}}\" [style.top]=\"(config.hiPlacement==='topLeft'||config.hiPlacement=='topRight')? config.hiTop:null\" [style.bottom]=\"(config.hiPlacement==='bottomLeft'||config.hiPlacement=='bottomRight')? config.hiBottom:null\" [style.right]=\"(config.hiPlacement==='bottomRight'||config.hiPlacement=='topRight')?'0px':null\" [style.left]=\"(config.hiPlacement==='topLeft'||config.hiPlacement=='bottomLeft')?'0px':null\"><hi-notification *ngFor=\"let message of messages; let i = index\" [hiMessage]=\"message\" [hiIndex]=\"i\"></hi-notification></div>\n  "
                },] },
    ];
    /** @nocollapse */
    NotificationContainerComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [NOTIFICATION_DEFAULT_CONFIG,] },] },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [NOTIFICATION_CONFIG,] },] },
    ]; };
    return NotificationContainerComponent;
}(MessageContainerComponent));
export { NotificationContainerComponent };

==> hibiscus.js-1.2.3.tgz: package/notification/notification-container.component.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Component, Inject, Optional } from '@angular/core';
import { MessageContainerComponent } from '../message/message-container.component';
import { NOTIFICATION_CONFIG, NOTIFICATION_DEFAULT_CONFIG } from './notification-config';
var NotificationContainerComponent = (function (_super) {
    __extends(NotificationContainerComponent, _super);
    function NotificationContainerComponent(defaultConfig, config) {
        return _super.call(this, defaultConfig, config) || this;
    }
    NotificationContainerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'hi-notification-container',
                    preserveWhitespaces: false,
                    template: "\n    <div class=\"hi-notification hi-notification-{{config.hiPlacement}}\" [style.top]=\"(config.hiPlacement==='topLeft'||config.hiPlacement=='topRight')? config.hiTop:null\" [style.bottom]=\"(config.hiPlacement==='bottomLeft'||config.hiPlacement=='bottomRight')? config.hiBottom:null\" [style.right]=\"(config.hiPlacement==='bottomRight'||config.hiPlacement=='topRight')?'0px':null\" [style.left]=\"(config.hiPlacement==='topLeft'||config.hiPlacement=='bottomLeft')?'0px':null\"><hi-notification *ngFor=\"let message of messages; let i = index\" [hiMessage]=\"message\" [hiIndex]=\"i\"></hi-notification></div>\n  "
                },] },
    ];
    NotificationContainerComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [NOTIFICATION_DEFAULT_CONFIG,] },] },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [NOTIFICATION_CONFIG,] },] },
    ]; };
    return NotificationContainerComponent;
}(MessageContainerComponent));
export { NotificationContainerComponent };
